diff --git a/synapse/config/appservice.py b/synapse/config/appservice.py
new file mode 100644
index 0000000000..399a716d80
--- /dev/null
+++ b/synapse/config/appservice.py
@@ -0,0 +1,31 @@
+# Copyright 2015 OpenMarket Ltd
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+from ._base import Config
+
+
+class AppServiceConfig(Config):
+
+ def __init__(self, args):
+ super(AppServiceConfig, self).__init__(args)
+ self.app_service_config_files = args.app_service_config_files
+
+ @classmethod
+ def add_arguments(cls, parser):
+ super(AppServiceConfig, cls).add_arguments(parser)
+ group = parser.add_argument_group("appservice")
+ group.add_argument(
+ "--app-service-config-files", type=str, nargs='+',
+ help="A list of application service config files to use."
+ )
diff --git a/synapse/config/homeserver.py b/synapse/config/homeserver.py
index 241afdf872..3edfadb98b 100644
--- a/synapse/config/homeserver.py
+++ b/synapse/config/homeserver.py
@@ -24,12 +24,13 @@ from .email import EmailConfig
from .voip import VoipConfig
from .registration import RegistrationConfig
from .metrics import MetricsConfig
+from .appservice import AppServiceConfig
class HomeServerConfig(TlsConfig, ServerConfig, DatabaseConfig, LoggingConfig,
RatelimitConfig, ContentRepositoryConfig, CaptchaConfig,
EmailConfig, VoipConfig, RegistrationConfig,
- MetricsConfig,):
+ MetricsConfig, AppServiceConfig,):
pass
diff --git a/synapse/config/server.py b/synapse/config/server.py
index 58a828cc4c..d4c223f348 100644
--- a/synapse/config/server.py
+++ b/synapse/config/server.py
@@ -110,7 +110,7 @@ class ServerConfig(Config):
with open(args.signing_key_path, "w") as signing_key_file:
syutil.crypto.signing_key.write_signing_keys(
signing_key_file,
- (syutil.crypto.signing_key.generate_singing_key("auto"),),
+ (syutil.crypto.signing_key.generate_signing_key("auto"),),
)
else:
signing_keys = cls.read_file(args.signing_key_path, "signing_key")
|
diff --git a/synapse/config/registration.py b/synapse/config/registration.py
index 4401e774d1..d5c8f4bf7b 100644
--- a/synapse/config/registration.py
+++ b/synapse/config/registration.py
@@ -25,11 +25,11 @@ class RegistrationConfig(Config):
def __init__(self, args):
super(RegistrationConfig, self).__init__(args)
- # `args.disable_registration` may either be a bool or a string depending
- # on if the option was given a value (e.g. --disable-registration=false
- # would set `args.disable_registration` to "false" not False.)
- self.disable_registration = bool(
- distutils.util.strtobool(str(args.disable_registration))
+ # `args.enable_registration` may either be a bool or a string depending
+ # on if the option was given a value (e.g. --enable-registration=true
+ # would set `args.enable_registration` to "true" not True.)
+ self.disable_registration = not bool(
+ distutils.util.strtobool(str(args.enable_registration))
)
self.registration_shared_secret = args.registration_shared_secret
@@ -39,11 +39,11 @@ class RegistrationConfig(Config):
reg_group = parser.add_argument_group("registration")
reg_group.add_argument(
- "--disable-registration",
+ "--enable-registration",
const=True,
- default=True,
+ default=False,
nargs='?',
- help="Disable registration of new users.",
+ help="Enable registration for new users.",
)
reg_group.add_argument(
"--registration-shared-secret", type=str,
@@ -53,8 +53,8 @@ class RegistrationConfig(Config):
@classmethod
def generate_config(cls, args, config_dir_path):
- if args.disable_registration is None:
- args.disable_registration = True
+ if args.enable_registration is None:
+ args.enable_registration = False
if args.registration_shared_secret is None:
args.registration_shared_secret = random_string_with_symbols(50)